<template>
  <win-md :title="setting.title" @close="close" width="1000px">
    <el-row :gutter="15">
      <!--左侧树形开始-->
      <el-col :span="6">
        <el-card style="height: calc(100vh - 400px);overflow-y: auto" shadow="never">
          <my-tree ref="searchTree" :tree-list="treeDataList" @setNode="nodeClick" @search="search"></my-tree>
        </el-card>
      </el-col>
      <!--左侧树形结束-->
      <!--右侧列表开始-->
      <el-col :span="18">
        <el-card class="box-card" shadow="never">
          <!--搜索条件-->
          <div class="filter-container">
            <my-search ref="searchBar" :items="chooseItems" @search="fifterForm"></my-search>
          </div>
          <el-row style="margin-top: 15px">
            <el-col>
              <!--列表-->
              <my-table ref="myTable" :parentSelectionsObject="setting.selections" :filter="filterFrom" :table="table"/>
            </el-col>
          </el-row>
        </el-card>
      </el-col>
    </el-row>
    <div slot="footer" align="center" class="dialog-footer">
      <my-button name="取消" site="form" @click="close"/>
      <my-button name="保存" site="form" @click="save"/>
    </div>
  </win-md>
</template>

<script>
import winMd from '@/components/win/win-md'
import myButton from '@/components/myButton/myButton'
import myTree from '@/components/myTree/index';
import MyTable from '@/components/myTable/myTable';
import SettingIplatform from "@/utils/settingIplatform";
import * as DateFormatter from "@/utils/DateFormatter";
import {getTree} from "@/api/baseSetting/finsystenant";
import chooseItems from './chooseItems'

export default {
  name: "chooseUser",
  components: {winMd, myButton, MyTable, myTree},
  props: {
    // setting 中须至少包含控制dialog显示或隐藏的属性,其余属性可拓展
    // 将添加/修改的大量数据及逻辑从列表页面中分离出来,避免列表页面代码过多,审查困难
    // 若此页面须回传数据至父页面,可在引用组件时添加事件,本页面使用this.$emit('事件名',参数1,参数2...)回传数据
    setting: {
      type: Object,
      default: () => {
      }
    }
  },
  data() {
    return {
      chooseItems: chooseItems,
      // 树数据
      treeDataList: [],
      // 搜索条件
      filterFrom: {
        tenantCode: 0,
        trnantId: 0,
        userName: null,
        userPhone: null,
      },
      // 表格数据
      table: {
        showIndex: true, // 是否显示序号
        showCheckBox: true,
        expand: false, // 是否显示详情数据
        url: SettingIplatform.apiBaseURL + '/pc/fin/sys/tenant/user/select/list?status=1', // 请求地址
        // 工具条
        tools: {
          columnsCtrl: {
            // 列控制按钮
            show: false,
          },
          generalExport: {
            // 通用导出按钮
            show: false,
          },
          // 自定义工具条按钮
          custom: [
            {
              name: '新增',
              click: () => {
                this.showAdd(null);
              },
            },
          ],
        },
        // 列信息
        columns: [
          {title: '人员姓名', field: 'userName', align: 'left'},
          {title: '员工编号', field: 'userCode', align: 'left'},
          {title: '手机号', field: 'userPhone', align: 'center', width: 120},
          {
            title: '创建时间',
            field: 'createTime',
            align: 'center',
            width: 160,
            formatter: (row) => {
              return {value: DateFormatter.LongToDateTime(row.createTime)};
            },
          },
        ],
        // 操作信息
        operation: {
          show: false, // 显示操作列
        },
        paging: {
          show: true, // 显示分页
          // 分页信息
          page: {
            small: false,
            pageNum: 1,
            pageSize: 10,
            total: 0,
          },
        },
      },
    }
  },
  created() {
    // 获取机构树
    this.initTreeData();
  },
  mounted() {
  },
  methods: {
    close() {
      this.$emit('close')
    },
    save() {
      let checkUsers = this.$refs.myTable.getChedkObject()
      if (checkUsers.length === 0) {
        this.$message.error('请选择人员')
        return false
      }
      this.$emit('checkUsers', checkUsers.map(item => {
        return {
          id: item.id,
          userName: item.userName
        }
      }))
    },
    // 左侧树初始化
    initTreeData() {
      getTree().then((res) => {
        const content = res || [];
        this.treeDataList.splice(0, this.treeDataList.length);
        this.treeDataList = content;
        if (this.treeDataList && this.treeDataList.length > 0) {
          this.tenantId = this.treeDataList[0].id;
          this.tenantCode = this.treeDataList[0].code;
        }
      });
    },
    nodeClick(param) {
      param = param || {};
      this.p = Object.assign(
        {},
        {
          id: param.id,
          name: param.name,
          code: param.code,
        },
      );
      if (this.p.code != undefined && this.p.code != null) {
        this.filterFrom.tenantCode = this.p.code;
        this.tenantId = this.p.id;
      } else {
        this.filterFrom.tenantCode = 0;
      }
      this.table.paging.page.pageNum = 1;
      this.search(1);
    },
    // 查询table列表
    search(pageNum) {
      if (pageNum != undefined) {
        this.$refs.myTable.search(pageNum);
      } else {
        this.$refs.myTable.search();
      }
    },
    // 重置
    reset() {
      this.filterFrom.tenantCode = null;
      this.filterFrom.userName = null;
      this.filterFrom.userPhone = null;
      this.search(1);
    },
    fifterForm(params) {
      this.filterFrom = Object.assign(this.filterFrom, params);
      this.search();
    },
  }
}
</script>

<style scoped>

</style>
